import * as THREE from 'three';
import { UseStore } from 'zustand';
import { RootState } from '../core/store';
export declare type Camera = THREE.OrthographicCamera | THREE.PerspectiveCamera;
export interface Intersection extends THREE.Intersection {
    eventObject: THREE.Object3D;
}
export declare type ThreeEvent<T> = T & Intersection & {
    intersections: Intersection[];
    stopped: boolean;
    unprojectedPoint: THREE.Vector3;
    ray: THREE.Ray;
    camera: Camera;
    stopPropagation: () => void;
    sourceEvent: T;
    delta: number;
};
export declare type DomEvent = ThreeEvent<PointerEvent> | ThreeEvent<MouseEvent> | ThreeEvent<WheelEvent>;
declare function createEvents(store: UseStore<RootState>): {
    onClick: (event: DomEvent, prepare?: boolean) => void;
    onContextMenu: (event: DomEvent, prepare?: boolean) => void;
    onDoubleClick: (event: DomEvent, prepare?: boolean) => void;
    onWheel: (event: DomEvent, prepare?: boolean) => void;
    onPointerDown: (event: DomEvent, prepare?: boolean) => void;
    onPointerUp: (event: DomEvent, prepare?: boolean) => void;
    onPointerLeave: (e: any) => void;
    onPointerMove: (event: DomEvent, prepare?: boolean) => Intersection[];
    onLostPointerCapture: (e: any) => void;
};
export { createEvents };
